/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id: crypttoken.h 1113 2007-01-10 09:14:16Z martin $
    begin       : Wed Mar 16 2005
    copyright   : (C) 2005 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef GWEN_CRYPT_TOKEN_PLUGIN_L_H
#define GWEN_CRYPT_TOKEN_PLUGIN_L_H


#include <gwenhywfar/ctplugin.h>


int GWEN_Crypt_Token_ModuleInit(void);
int GWEN_Crypt_Token_ModuleFini(void);



#endif


